<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Italiano [IT]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=424
Author: Piwigo team
Author URI: http://piwigo.org
*/

// Langage informations
$lang_info['language_name'] = 'Italiano';
$lang_info['country'] = 'Italia';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'it';
$lang_info['zero_plural'] = false;

$lang['%d Kb'] = '%d Ko';
$lang['%d album updated'] = '%d album aggiornato';
$lang['%d albums updated'] = '%d album aggiornati';
$lang['%d comment to validate'] = '%d commento utente da approvare';
$lang['%d comments to validate'] = '%d commenti utente da approvare';
$lang['%d new comment'] = '%d nuovo commento utente';
$lang['%d new comments'] = '%d nuovi commenti utente';
$lang['%d comment'] = '%d commento';
$lang['%d comments'] = '%d commenti';
$lang['%d hit'] = 'vista %d volte';
$lang['%d hits'] = 'viste %d volte';
$lang['%d new photo'] = '%d nuova foto';
$lang['%d new photos'] = '%d nuove foto';
$lang['%d new user'] = '%d nuovo utente';
$lang['%d new users'] = '%d nuovi utenti';
$lang['About'] = 'Informazioni su...';
$lang['All tags'] = 'Tutti i tags';
$lang['Any tag'] = 'Qualsiasi tag';
$lang['At least one listed rule must be satisfied.'] = 'Almeno una delle regole elencate deve essere soddisfatta.';
$lang['At least one tag must match'] = 'Almeno un tag deve corrispondere';
$lang['Albums'] = 'Album';
$lang['Album'] = 'Album';
$lang['Close this window'] = 'Chiudi questa finestra';
$lang['Complete RSS feed (photos, comments)'] = 'Feed RSS completo (foto, commenti)';
$lang['Confirm Password'] = 'Conferma la Password';
$lang['Connection settings'] = 'Parametri di connessione';
$lang['Login'] = 'Connessione';
$lang['Contact webmaster'] = 'Contattare il webmaster';
$lang['Create a new account'] = 'Creare un nuovo account utente?';
$lang['Created on'] = 'Creato il';
$lang['Creation date'] = 'Data di creazione';
$lang['Current password is wrong'] = 'La password non è esatta';
$lang['Dimensions'] = 'Dimensioni';
$lang['Display'] = 'Visualizzazione';
$lang['Each listed rule must be satisfied.'] = 'Tutti i criteri devono essere soddisfatti';
$lang['Email address'] = 'Indirizzo email';
$lang['Enter your personnal informations'] = 'Inserire le informazioni personali';
$lang['Error sending email'] = 'Errore durante l\'invio dell\'email';
$lang['File name'] = 'Nome file';
$lang['File'] = 'File';
$lang['Filesize'] = 'Dimensione';
$lang['Filter and display'] = 'Filtra e visualizza';
$lang['Filter'] = 'Filtro';
$lang['Forgot your password?'] = 'Password dimenticata ?';
$lang['Go through the gallery as a visitor'] = 'Visita la galleria come ospite';
$lang['Help'] = 'Aiuto';
$lang['Identification'] = 'Identificazione';
$lang['Photos only RSS feed'] = 'Feed RSS solo per le foto';
$lang['Keyword'] = 'Parola chiave';
$lang['Links'] = 'Links';
$lang['N/A'] = 'Non disponibile';
$lang['New on %s'] = 'Nuovo il %s';
$lang['New password confirmation does not correspond'] = 'La conferma della nuova password non corrisponde';
$lang['Notification'] = 'Notifiche RSS';
$lang['Number of items'] = 'Numero di elementi';
$lang['Original dimensions'] = 'Dimensioni originali';
$lang['Password forgotten'] = 'Password dimenticata';
$lang['Password'] = 'Password';
$lang['Post date'] = 'Data d\'invio';
$lang['Posted on'] = 'Inviato il';
$lang['Profile'] = 'Profilo';
$lang['Quick connect'] = 'Connessione veloce';
$lang['RSS feed'] = 'Feed RSS';
$lang['Register'] = 'Registrati';
$lang['Registration'] = 'Registrazione';
$lang['Related tags'] = 'Tags correlati';
$lang['Reset'] = 'Cancellare';
$lang['Retrieve password'] = 'Recuperare la password';
$lang['Search rules'] = 'Criteri di ricerca';
$lang['Search tags'] = 'Ricercare i tags';
$lang['Search'] = 'Cerca';
$lang['display available tags'] = 'Mostra i tags disponibili';
$lang['Since'] = 'Dal';
$lang['Sort by'] = 'Ordina per';
$lang['Sort order'] = 'Ordinamento';
$lang['Tag'] = 'Tag';
$lang['Tags'] = 'Tags';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'L\'RSS Feed notifica delle novità della galleria: nuove foto, nuovi album, nuovi commenti. Da usare con un lettore RSS Feed.';
$lang['Unknown feed identifier'] = 'Identificatore di flusso sconosciuto';
$lang['User comments'] = 'Commenti utenti';
$lang['Username'] = 'Nome utente';
$lang['Visits'] = 'Visite';
$lang['Webmaster'] = 'Webmaster';
$lang['Week %d'] = 'Settimana %d';
$lang['About Piwigo'] = 'Informazioni su Piwigo';
$lang['You are not authorized to access the requested page'] = 'Non sei autorizzato a visualizzare la pagina richiesta';
$lang['add to caddie'] = 'Aggiungi al cestino';
$lang['add this photo to your favorites'] = 'Aggiungi la pagina ai tuoi preferiti';
$lang['Administration'] = 'Amministrazione';
$lang['all'] = 'tutto';
$lang['ascending'] = 'ascendente';
$lang['author(s) : %s'] = 'autore(i) : %s';
$lang['Expand all albums'] = 'Espandere tutti gli album';
$lang['posted after %s (%s)'] = 'disponibile dopo il %s (%s)';
$lang['posted before %s (%s)'] = 'disponibile prima del %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'disponibile tra %s (%s) e il %s (%s)';
$lang['posted on %s'] = 'disponibile il %s';
$lang['Best rated'] = 'I più votati';
$lang['display best rated photos'] = 'Mostra le foto le più votate';
$lang['caddie'] = 'Cestino';
$lang['Calendar'] = 'Calendario';
$lang['All'] = 'Tutto';
$lang['display each day with photos, month per month'] = 'Mostra anno per anno, mese per mese, giorno per giorno';
$lang['View'] = 'Vista';
$lang['chronology_monthly_calendar'] = 'Calendario mensile';
$lang['chronology_monthly_list'] = 'Lista mensile';
$lang['chronology_weekly_list'] = 'Lista settimanale';
$lang['Click here if your browser does not automatically forward you'] = 'Cliccare qui se non siete reindirizzati automaticamente.';
$lang['comment date'] = 'data del commento';
$lang['Comment'] = 'Commento';
$lang['Your comment has been registered'] = 'Il vostro commento è stato registrato';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Sistema di sicurezza anti-flood: attendere prima di aggiungere un nuovo commento';
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = 'Il vostro commento NON è stato registrato perchè non rispetta le regole di convalidazione';
$lang['An administrator must authorize your comment before it is visible.'] = 'Un amministratore deve autorizzare il tuo commento affinchè sia visibile.';
$lang['This login is already used by another user'] = 'Questo nome utente esiste già';
$lang['Comments'] = 'Commenti';
$lang['Add a comment'] = 'Aggiungi un commento';
$lang['created after %s (%s)'] = 'creata dopo il %s (%s)';
$lang['created before %s (%s)'] = 'creata prima del %s (%s)';
$lang['created between %s (%s) and %s (%s)'] = 'creata tra il %s (%s) e il %s (%s)';
$lang['created on %s'] = 'creata il %s';
$lang['Customize'] = 'Profilo';
$lang['Your Gallery Customization'] = 'Personalizzare la visualizzazione della Galleria ';
$lang['day'][0] = 'Domenica';
$lang['day'][1] = 'Lunedì';
$lang['day'][2] = 'Martedì';
$lang['day'][3] = 'Mercoledì';
$lang['day'][4] = 'Giovedì';
$lang['day'][5] = 'Venerdì';
$lang['day'][6] = 'Sabato';
$lang['Default'] = 'Di default';
$lang['delete this photo from your favorites'] = 'Cancellare questa foto dalle vostre preferite';
$lang['Delete'] = 'Cancellare';
$lang['descending'] = 'discendente';
$lang['download'] = 'Scaricare';
$lang['download this file'] = 'Scaricare questo file';
$lang['edit'] = 'Modificare';
$lang['wrong date'] = 'data errata';
$lang['excluded'] = 'Escluso';
$lang['Your favorites'] = 'Le mie preferite';
$lang['display your favorites photos'] = 'Mostra le mie foto preferite';
$lang['Favorites'] = 'Preferite';
$lang['First'] = 'Primo';
$lang['The gallery is locked for maintenance. Please, come back later.'] = 'La galleria è chiusa per manutenzione. Torna più tardi.';
$lang['Page generated in'] = 'Pagina generata in';
$lang['guest'] = 'ospite';
$lang['Hello'] = 'Ciao';
$lang['available for administrators only'] = 'Disponibile solo per gli amministratori';
$lang['display this album'] = 'Mostra le foto alle radici dell\'album';
$lang['display last user comments'] = 'Mostra gli ultimi commenti degli utenti';
$lang['customize the appareance of the gallery'] = 'Personalizza l\'aspetto della galleria';
$lang['search'] = 'Cerca nella galleria';
$lang['Home'] = 'Home';
$lang['in this album'] = 'In questo album';
$lang['in %d sub-album'] = 'in %d sub-album';
$lang['in %d sub-albums'] = 'in %d sub-album';
$lang['included'] = 'incluso';
$lang['Invalid password!'] = 'Password non valida !';
$lang['Language'] = 'Lingua';
$lang['last %d days'] = 'Ultimi %d giorni';
$lang['Last'] = 'Ultima';
$lang['Logout'] = 'Logout';
$lang['E-mail address'] = $lang['Email address'];
$lang['obligatory'] = 'obbligatorio';
$lang['Maximum photo height'] = 'Altezza massima delle foto';
$lang['Maximum height must be a number superior to 50'] = 'L\'altezza massima deve essere un numero superiore a 50';
$lang['Maximum photo width'] = 'Larghezza massima delle foto';
$lang['Maximum width must be a number superior to 50'] = 'La larghezza massima deve essere un numero superiore a 50';
$lang['display a calendar by creation date'] = 'Mostra il calendario per data di creazione';
$lang['display all photos in all sub-albums'] = 'Mostrare tutte le foto in tutti gli album e sub-album';
$lang['return to normal view mode'] = 'Ritorna alla visualizzazione normale';
$lang['display a calendar by posted date'] = 'Mostra il calendario per data d\'inserimento nella galleria';
$lang['month'][10] = 'Ottobre';
$lang['month'][11] = 'Novembre';
$lang['month'][12] = 'Dicembre';
$lang['month'][1] = 'Gennaio';
$lang['month'][2] = 'Febbraio';
$lang['month'][3] = 'Marzo';
$lang['month'][4] = 'Aprile';
$lang['month'][5] = 'Maggio';
$lang['month'][6] = 'Giugno';
$lang['month'][7] = 'Luglio';
$lang['month'][8] = 'Agosto';
$lang['month'][9] = 'Settembre';
$lang['Most visited'] = 'Le più viste';
$lang['display most visited photos'] = 'Mostra le foto le più viste';
$lang['The number of photos per page must be a not null scalar'] = 'Il numero di foto per pagina deve essere un intero non nullo';
$lang['Number of photos per page'] = 'Numero di miniature per pagina';
$lang['Unknown identifier'] = 'Identificante sconosciuto';
$lang['New password'] = 'Nuova password';
$lang['Rate this photo'] = 'Vota questa foto';
$lang['Next'] = 'Prossima';
$lang['no rate'] = 'nessun voto';
$lang['Photos posted within the last %d day.'] = 'Foto pubblicate nelle ultime 24 ore.';
$lang['Photos posted within the last %d days.'] = 'Foto pubblicate negli ultimi %d giorni.';
$lang['password updated'] = 'password aggiornata';
$lang['Recent period must be a positive integer value'] = 'Il periodo deve essere un valore intero positivo';
$lang['photo'] = 'foto';
$lang['Click on the photo to see it in high definition'] = 'Cliccare sulla foto per vederla in alta definizione';
$lang['Show file metadata'] = 'Mostrare i metadati del file';
$lang['Powered by'] = 'Sito realizzato grazie a';
$lang['Preferences'] = 'Preferenze';
$lang['Previous'] = 'Precendente';
$lang['Random photos'] = 'Foto a caso';
$lang['display a set of random photos'] = 'Mostra un set di foto in modo casuale';
$lang['Recent albums'] = 'Album recenti';
$lang['display recently updated albums'] = 'Mostrare gli album caricati di recente';
$lang['Recent period'] = 'Periodo recente';
$lang['Recent photos'] = 'Ultime foto';
$lang['display most recent photos'] = 'Mostra le foto più recenti';
$lang['Redirection...'] = 'Reindirizzamento in corso...';
$lang['Please, enter a login'] = 'Inserire nome utente, grazie';
$lang['login mustn\'t end with a space character'] = 'Il nome utente non deve finire con uno spazio';
$lang['login mustn\'t start with a space character'] = 'Il nome utente non deve iniziare con uno spazio';
$lang['this login is already used'] = 'Nome utente già esistente';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'l\'indirizzo email deve essere del tipo xxx@yyy.eee (ad esempio: cippalippa@libero.rio)';
$lang['please enter your password again'] = 'Reinserire la password, grazie.';
$lang['Auto login'] = 'Conessione automatica';
$lang['remove this tag from the list'] = 'Eliminare questo tag dall\'elenco';
$lang['representative'] = 'rappresentative';
$lang['Search for Author'] = 'Cercare un Autore';
$lang['Search in albums'] = 'Cercare negli album';
$lang['Search by Date'] = 'Cercare per data';
$lang['Date'] = 'data';
$lang['End-Date'] = 'Data di fine';
$lang['Kind of date'] = 'Tipo data';
$lang['Search for words'] = 'Cercare le parole';
$lang['Search for all terms'] = 'Cercare tutte le parole';
$lang['Search for any terms'] = 'Cercare una qualsiasi delle parole';
$lang['Empty query. No criteria has been entered.'] = 'Ricerca incompleta. Nessun criterio di ricerca inserito.';
$lang['Search Options'] = 'Opzioni di ricerca';
$lang['Search results'] = 'Risultato della ricerca';
$lang['Search in sub-albums'] = 'Cercare nei sub-album';
$lang['searched words : %s'] = 'parole cercate : %s';
$lang['Contact'] = 'Contattare';
$lang['set as album representative'] = 'Impostare come rappresentativa per l\'album';
$lang['Show number of comments'] = 'Mostrare il numero dei commenti';
$lang['Show number of hits'] = 'Mostrare il numero di visualizzazioni';
$lang['slideshow'] = 'Avviare la proiezione di diapositive';
$lang['stop the slideshow'] = 'fermare le diapositive';
$lang['Specials'] = 'Speciale';
$lang['SQL queries in'] = 'Queries SQL in';
$lang['display only recently posted photos'] = 'mostra solo le foto pubblicate di recente';
$lang['return to the display of all photos'] = 'ritornare alla visualizzazione di tutte le foto';
$lang['the beginning'] = 'L\'inizio';
$lang['Interface theme'] = 'Tema dell\'interfaccia';
$lang['Thumbnails'] = 'Miniature';
$lang['Menu'] = 'Menu';
$lang['A comment on your site'] = 'Un commento sul sito';
$lang['today'] = 'Oggi';
$lang['Update your rating'] = 'Aggiorna il tuo voto';
$lang['wrong filename'] = 'nome della directory errata';
$lang['the username must be given'] = 'nome utente obbligatorio';
$lang['useful when password forgotten'] = 'utile se si dimentica la password';
$lang['Quick search'] = 'Ricerca rapida';
$lang['Connected user: %s'] = 'Utente(i) connesso(i): %s';
$lang['IP: %s'] = 'IP: %s';
$lang['Browser: %s'] = 'Browser: %s';
$lang['Author: %s'] = 'Autore: %s';
$lang['Comment: %s'] = 'Commento: %s';
$lang['Comment by %s'] = 'Commento per %s';
$lang['User: %s'] = 'Utente: %s';
$lang['Email: %s'] = 'Email: %s';
$lang['Admin: %s'] = 'Amministrazione: %s';
$lang['Registration of %s'] = 'Registrazione di %s';
$lang['Album: %s'] = 'Album: %s';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Lo status dell\'utente "guest" non è conforme, viene usato lo status di default. Per favore avvisa il webmaster.';
$lang['this email address is already in use'] = 'un utente usa già questo indirizzo mail';
$lang['Album results for'] = 'Risultati degli album per';
$lang['Tag results for'] = 'Risultato dei tag per';
$lang['from %s to %s'] = 'da %s a %s';
$lang['Play of slideshow'] = 'Avvia proiezione';
$lang['Pause of slideshow'] = 'Pausa proiezione';
$lang['Repeat the slideshow'] = 'Ricominciare proiezione';
$lang['Not repeat the slideshow'] = 'Non ricominciare proiezione';
$lang['Reduce diaporama speed'] = 'Ralentare la velocità proiezione';
$lang['Accelerate diaporama speed'] = 'Accelerare la velocità proiezione';
$lang['Submit'] = 'Confermare';
$lang['Yes'] = 'Sì';
$lang['No'] = 'No';
$lang['%d photo']='%d foto';
$lang['%d photos']='%d foto';
$lang['%d photo is also linked to current tags'] = '%d foto è anche connessa ai tag correnti';
$lang['%d photos are also linked to current tags'] = '%d foto sono anche connesse ai tag correnti';
$lang['display photos linked to this tag'] = 'Mostrare le foto connesse solo a questo tag';
$lang['photos posted during the last %d days'] = 'foto aggiunte durante gli ultimi %d giorni';
$lang['Piwigo Help'] = 'Help di Piwigo';
$lang['Rank'] = 'Rang';
$lang['group by letters'] = 'ragruppare per lettera';
$lang['letters'] = 'lettere';
$lang['show tag cloud'] = 'mostrare la nuvola di tags';
$lang['cloud'] = 'nuvola';
$lang['Reset to default values'] = 'Ripristinare le impostazioni predefinite';
$lang['delete all photos from your favorites'] = 'Cancellare tutte le foto dai vostri favoriti';
$lang['Sent by'] = 'Mandato da';
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'I cookies sono bloccati o non supportati dal vostro browser. Dovete attivare i cookie per connettervi.';
$lang['edit this comment'] = 'Modificare questo commento';
$lang['Edit a comment'] = 'Modificare un commento';
$lang['Are you sure?'] = 'Sei sicuro?';
$lang['(!) This comment requires validation'] = '(!) Questo commento deve essere approvato';
$lang['Welcome'] = 'Benvenuto';
$lang['Welcome to your Piwigo photo gallery!'] = 'Benvenuto nella vostra galleria fotografica Piwigo !';
$lang['... or browse your empty gallery'] = '... o naviga nella nostra galleria vuota';
$lang['... or please deactivate this message, I will find my way by myself'] = '... oppure disattiva questo messaggio, voglio riuscirci da solo';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Salve %s, la vostra galleria fotografica Piwigo è vuota!';
$lang['I want to add photos'] = 'Voglio aggiungere delle foto';
$lang['Manage this user comment: %s'] = 'Gestire questo commento: %s';
$lang['Email address is missing. Please specify an email address.'] = 'Manca l\'indirizzo Email. Per favore specificarne uno.';
$lang['This author modified following comment:'] = 'Questo autore ha modificato il commento seguente:';
$lang['This author removed the comment with id %d'] = 'Questo autore ha cancellato il commento con  l\'ID %d';
$lang['delete this comment'] = 'Cancellare questo commento';
$lang['validate this comment'] = 'Approvare questo commento';
$lang['html tags are not allowed in login'] = 'I tag HTML non sono ammessi nel login';
$lang['Enter a username or email address'] = 'Inserisci il tuo nome utente o indirizzo email';
$lang['Invalid username or email'] = 'Nome utente o indirizzo email non valido';
$lang['Password reset is not allowed for this user'] = 'Il rinnovo della password non è consentito per questo utente';
$lang['User "%s" has no email address, password reset is not possible'] = 'L\'utente "%s" non ha nessun indirizzo email, il rinnovo della password è impossibile';
$lang['Someone requested that the password be reset for the following user account:'] = 'Qualcuno ha chiesto di rinnovare la propria password per l\'utente seguente :';
$lang['Username "%s" on gallery %s'] = 'Utente "%s" sur la galerie %s';
$lang['To reset your password, visit the following address:'] = 'Per rinnovare la vostra password, cliccare sul link qui sotto :';
$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Se si tratta di un\'errore, ignorare questo messaggio e la richiesta non sarà presa in considerazione';
$lang['Password Reset'] = 'Rinnovare la vostra password';
$lang['Check your email for the confirmation link'] = 'Controllare la posta elettronica per trovare il link di conferma';
$lang['Invalid key'] = 'Chiave non valida';
$lang['The passwords do not match'] = 'Le password non coincidono';
$lang['Your password has been reset'] = 'La password è stata reimpostata';
$lang['Return to home page'] = 'Ritornare alla home page';
$lang['Please enter your username or email address.'] = 'Grazie d\'inserire il nome utente o l\'indirizzo email';
$lang['You will receive a link to create a new password via email.'] = 'Via email, riceverete un link da cliccare per rinnovare la vostra password';
$lang['Username or email'] = 'Nome utente o indirizzo email';
$lang['Change my password'] = 'Cambiare la mia password';
$lang['Enter your new password below.'] = 'Immettere la nuova password qui sotto';
$lang['Author'] = 'Autore';
$lang['%d rates'] = '%d voti';
$lang['Rating score'] = 'Punteggio';
$lang['Reset Password'] = 'Reinizzializzare la password';
$lang['EXIF Metadata'] = 'Dati EXIF';
$lang['IPTC Metadata'] = 'Dati IPTC';

?>